==> epiphany-debuginfo-3.8.2-2.tar.xz: usr/src/debug/epiphany-3.8.2-2/lib/history/ephy-history-type-builtins.c <==



#include <config.h>

#include "ephy-history-type-builtins.h"


/* enumerations from "/usr/src/ports/epiphany/epiphany-3.8.2-2.i686/src/epiphany-3.8.2/lib/history/ephy-history-types.h" */
#include "/usr/src/ports/epiphany/epiphany-3.8.2-2.i686/src/epiphany-3.8.2/lib/history/ephy-history-types.h"
GType
ephy_history_page_visit_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
  {
    static const GEnumValue _ephy_history_page_visit_type_values[] = {
      { EPHY_PAGE_VISIT_NONE, "EPHY_PAGE_VISIT_NONE", "none" },
      { EPHY_PAGE_VISIT_LINK, "EPHY_PAGE_VISIT_LINK", "link" },
      { EPHY_PAGE_VISIT_TYPED, "EPHY_PAGE_VISIT_TYPED", "typed" },
      { EPHY_PAGE_VISIT_MANUAL_SUBFRAME, "EPHY_PAGE_VISIT_MANUAL_SUBFRAME", "manual-subframe" },
      { EPHY_PAGE_VISIT_AUTO_SUBFRAME, "EPHY_PAGE_VISIT_AUTO_SUBFRAME", "auto-subframe" },
      { EPHY_PAGE_VISIT_STARTUP, "EPHY_PAGE_VISIT_STARTUP", "startup" },
      { EPHY_PAGE_VISIT_FORM_SUBMISSION, "EPHY_PAGE_VISIT_FORM_SUBMISSION", "form-submission" },
      { EPHY_PAGE_VISIT_FORM_RELOAD, "EPHY_PAGE_VISIT_FORM_RELOAD", "form-reload" },
      { EPHY_PAGE_VISIT_BOOKMARK, "EPHY_PAGE_VISIT_BOOKMARK", "bookmark" },
      { EPHY_PAGE_VISIT_HOMEPAGE, "EPHY_PAGE_VISIT_HOMEPAGE", "homepage" },
      { 0, NULL, NULL }
    };

    type = g_enum_register_static ("EphyHistoryPageVisitType", _ephy_history_page_visit_type_values);
  }

  return type;
}

GType
ephy_history_url_property_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
  {
    static const GEnumValue _ephy_history_url_property_values[] = {
      { EPHY_HISTORY_URL_TITLE, "EPHY_HISTORY_URL_TITLE", "title" },
      { 0, NULL, NULL }
    };

    type = g_enum_register_static ("EphyHistoryURLProperty", _ephy_history_url_property_values);
  }

  return type;
}

GType
ephy_history_sort_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
  {
    static const GEnumValue _ephy_history_sort_type_values[] = {
      { EPHY_HISTORY_SORT_NONE, "EPHY_HISTORY_SORT_NONE", "none" },
      { EPHY_HISTORY_SORT_MRV, "EPHY_HISTORY_SORT_MRV", "mrv" },
      { EPHY_HISTORY_SORT_LRV, "EPHY_HISTORY_SORT_LRV", "lrv" },
      { EPHY_HISTORY_SORT_MV, "EPHY_HISTORY_SORT_MV", "mv" },
      { EPHY_HISTORY_SORT_LV, "EPHY_HISTORY_SORT_LV", "lv" },
      { 0, NULL, NULL }
    };

    type = g_enum_register_static ("EphyHistorySortType", _ephy_history_sort_type_values);
  }

  return type;
}

==> epiphany-debuginfo-3.8.2-3.tar.xz: usr/src/debug/epiphany-3.8.2-3/lib/history/ephy-history-type-builtins.c <==



#include <config.h>

#include "ephy-history-type-builtins.h"


/* enumerations from "/usr/src/ports/epiphany/epiphany-3.8.2-3.x86_64/src/epiphany-3.8.2/lib/history/ephy-history-types.h" */
#include "/usr/src/ports/epiphany/epiphany-3.8.2-3.x86_64/src/epiphany-3.8.2/lib/history/ephy-history-types.h"
GType
ephy_history_page_visit_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
  {
    static const GEnumValue _ephy_history_page_visit_type_values[] = {
      { EPHY_PAGE_VISIT_NONE, "EPHY_PAGE_VISIT_NONE", "none" },
      { EPHY_PAGE_VISIT_LINK, "EPHY_PAGE_VISIT_LINK", "link" },
      { EPHY_PAGE_VISIT_TYPED, "EPHY_PAGE_VISIT_TYPED", "typed" },
      { EPHY_PAGE_VISIT_MANUAL_SUBFRAME, "EPHY_PAGE_VISIT_MANUAL_SUBFRAME", "manual-subframe" },
      { EPHY_PAGE_VISIT_AUTO_SUBFRAME, "EPHY_PAGE_VISIT_AUTO_SUBFRAME", "auto-subframe" },
      { EPHY_PAGE_VISIT_STARTUP, "EPHY_PAGE_VISIT_STARTUP", "startup" },
      { EPHY_PAGE_VISIT_FORM_SUBMISSION, "EPHY_PAGE_VISIT_FORM_SUBMISSION", "form-submission" },
      { EPHY_PAGE_VISIT_FORM_RELOAD, "EPHY_PAGE_VISIT_FORM_RELOAD", "form-reload" },
      { EPHY_PAGE_VISIT_BOOKMARK, "EPHY_PAGE_VISIT_BOOKMARK", "bookmark" },
      { EPHY_PAGE_VISIT_HOMEPAGE, "EPHY_PAGE_VISIT_HOMEPAGE", "homepage" },
      { 0, NULL, NULL }
    };

    type = g_enum_register_static ("EphyHistoryPageVisitType", _ephy_history_page_visit_type_values);
  }

  return type;
}

GType
ephy_history_url_property_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
  {
    static const GEnumValue _ephy_history_url_property_values[] = {
      { EPHY_HISTORY_URL_TITLE, "EPHY_HISTORY_URL_TITLE", "title" },
      { 0, NULL, NULL }
    };

    type = g_enum_register_static ("EphyHistoryURLProperty", _ephy_history_url_property_values);
  }

  return type;
}

GType
ephy_history_sort_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
  {
    static const GEnumValue _ephy_history_sort_type_values[] = {
      { EPHY_HISTORY_SORT_NONE, "EPHY_HISTORY_SORT_NONE", "none" },
      { EPHY_HISTORY_SORT_MRV, "EPHY_HISTORY_SORT_MRV", "mrv" },
      { EPHY_HISTORY_SORT_LRV, "EPHY_HISTORY_SORT_LRV", "lrv" },
      { EPHY_HISTORY_SORT_MV, "EPHY_HISTORY_SORT_MV", "mv" },
      { EPHY_HISTORY_SORT_LV, "EPHY_HISTORY_SORT_LV", "lv" },
      { 0, NULL, NULL }
    };

    type = g_enum_register_static ("EphyHistorySortType", _ephy_history_sort_type_values);
  }

  return type;
}
